import axios from '@/utils/axios'
import { type AxiosResponse } from 'axios'

export interface LoginInputDto {
  email: string
  password: string
}

export interface CreateUserDto {
  email: string
  password: string
  username?: string
}

export interface Token {
  accessToken: string
  refreshToken: string
}

export interface TokenRefreshPayload {
  refreshToken: string
}

export async function register(data: CreateUserDto) {
  return axios.post<Token>('/api/auth/register', data)
}

export async function login(data: LoginInputDto) {
  return axios.post<Token>('/api/auth/login', data)
}

let refreshing: Promise<AxiosResponse<Token>> | null

export async function refreshToken(data: TokenRefreshPayload) {
  if (!refreshing) {
    refreshing = axios.put<Token>('/api/auth/token', data).finally(() => {
      refreshing = null
    })
  }
  return refreshing
}
